summaryrefslogtreecommitdiffstats
path: root/khtml/khtmlpart_p.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /khtml/khtmlpart_p.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/khtmlpart_p.h')
-rw-r--r--khtml/khtmlpart_p.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/khtml/khtmlpart_p.h b/khtml/khtmlpart_p.h
index 0047dde54..871ea62d7 100644
--- a/khtml/khtmlpart_p.h
+++ b/khtml/khtmlpart_p.h
@@ -72,7 +72,7 @@ namespace KParts
namespace khtml
{
- class KDE_EXPORT ChildFrame : public QObject
+ class KDE_EXPORT ChildFrame : public TQObject
{
Q_OBJECT
public:
@@ -118,7 +118,7 @@ namespace khtml
struct KHTMLFrameList : public TQValueList<khtml::ChildFrame*>
{
- Iterator find( const TQString &name ) KDE_NO_EXPORT;
+ Iterator tqfind( const TQString &name ) KDE_NO_EXPORT;
};
typedef KHTMLFrameList::ConstIterator ConstFrameIt;
@@ -127,7 +127,7 @@ typedef KHTMLFrameList::Iterator FrameIt;
static int khtml_part_dcop_counter = 0;
-class KHTMLWalletQueue : public QObject
+class KHTMLWalletQueue : public TQObject
{
Q_OBJECT
public:
@@ -214,8 +214,8 @@ public:
m_jobPercent = 0;
m_haveEncoding = false;
m_activeFrame = 0L;
- m_find = 0;
- m_findDialog = 0;
+ m_tqfind = 0;
+ m_tqfindDialog = 0;
m_ssl_in_use = false;
m_jsedlg = 0;
m_formNotification = KHTMLPart::NoNotification;
@@ -516,29 +516,29 @@ public:
};
TQValueList<StringPortion> m_stringPortions;
- KFind *m_find;
- KFindDialog *m_findDialog;
+ KFind *m_tqfind;
+ KFindDialog *m_tqfindDialog;
- struct findState
+ struct tqfindState
{
- findState() : options( 0 ), last_dir( -1 ) {}
+ tqfindState() : options( 0 ), last_dir( -1 ) {}
TQStringList history;
TQString text;
int options;
int last_dir; // -1=unknown,0=forward,1=backward
};
- findState m_lastFindState;
+ tqfindState m_lastFindState;
KJSErrorDlg *m_jsedlg;
- DOM::NodeImpl *m_findNode; // current node
- DOM::NodeImpl *m_findNodeEnd; // end node
- DOM::NodeImpl *m_findNodeStart; // start node
- DOM::NodeImpl *m_findNodePrevious; // previous node used for find
- int m_findPos; // current pos in current node
- int m_findPosEnd; // pos in end node
- int m_findPosStart; // pos in start node
+ DOM::NodeImpl *m_tqfindNode; // current node
+ DOM::NodeImpl *m_tqfindNodeEnd; // end node
+ DOM::NodeImpl *m_tqfindNodeStart; // start node
+ DOM::NodeImpl *m_tqfindNodePrevious; // previous node used for tqfind
+ int m_tqfindPos; // current pos in current node
+ int m_tqfindPosEnd; // pos in end node
+ int m_tqfindPosStart; // pos in start node
/////////
//TQGuardedPtr<KParts::Part> m_activeFrame;